==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_functions/gridrequest/GRID.java <==

package net.datastream.schemas.mp_functions.gridrequest;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="GRID_NAME" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="USER_FUNCTION_NAME" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="GRID_ID" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="NUMBER_OF_ROWS_FIRST_RETURNED" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="CURSOR_POSITION" type="{http://schemas.datastream.net/MP_functions/GridRequest}CURSOR_POSITION" />
 *       &lt;attribute name="TAB_NAME" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="RESULT_IN_SAXORDER" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="TERSERESPONSE" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="LOCALIZE_RESULT" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "GRID")
public class GRID {

    @XmlAttribute(name = "GRID_NAME")
    protected String grid_NAME;
    @XmlAttribute(name = "USER_FUNCTION_NAME")
    protected String user_FUNCTION_NAME;
    @XmlAttribute(name = "GRID_ID")
    protected BigInteger grid_ID;
    @XmlAttribute(name = "NUMBER_OF_ROWS_FIRST_RETURNED")
    protected BigInteger number_OF_ROWS_FIRST_RETURNED;
    @XmlAttribute(name = "CURSOR_POSITION")
    protected BigInteger cursor_POSITION;
    @XmlAttribute(name = "TAB_NAME")
    protected String tab_NAME;
    @XmlAttribute(name = "RESULT_IN_SAXORDER")
    protected String result_IN_SAXORDER;
    @XmlAttribute(name = "TERSERESPONSE")
    protected String terseresponse;
    @XmlAttribute(name = "LOCALIZE_RESULT")
    protected String localize_RESULT;

    /**
     * Gets the value of the grid_NAME property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRID_NAME() {
        return grid_NAME;
    }

    /**
     * Sets the value of the grid_NAME property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRID_NAME(String value) {
        this.grid_NAME = value;
    }

    /**
     * Gets the value of the user_FUNCTION_NAME property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSER_FUNCTION_NAME() {
        return user_FUNCTION_NAME;
    }

    /**
     * Sets the value of the user_FUNCTION_NAME property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSER_FUNCTION_NAME(String value) {
        this.user_FUNCTION_NAME = value;
    }

    /**
     * Gets the value of the grid_ID property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getGRID_ID() {
        return grid_ID;
    }

    /**
     * Sets the value of the grid_ID property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setGRID_ID(BigInteger value) {
        this.grid_ID = value;
    }

    /**
     * Gets the value of the number_OF_ROWS_FIRST_RETURNED property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNUMBER_OF_ROWS_FIRST_RETURNED() {
        return number_OF_ROWS_FIRST_RETURNED;
    }

    /**
     * Sets the value of the number_OF_ROWS_FIRST_RETURNED property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNUMBER_OF_ROWS_FIRST_RETURNED(BigInteger value) {
        this.number_OF_ROWS_FIRST_RETURNED = value;
    }

    /**
     * Gets the value of the cursor_POSITION property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getCURSOR_POSITION() {
        return cursor_POSITION;
    }

    /**
     * Sets the value of the cursor_POSITION property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setCURSOR_POSITION(BigInteger value) {
        this.cursor_POSITION = value;
    }

    /**
     * Gets the value of the tab_NAME property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTAB_NAME() {
        return tab_NAME;
    }

    /**
     * Sets the value of the tab_NAME property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTAB_NAME(String value) {
        this.tab_NAME = value;
    }

    /**
     * Gets the value of the result_IN_SAXORDER property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESULT_IN_SAXORDER() {
        return result_IN_SAXORDER;
    }

    /**
     * Sets the value of the result_IN_SAXORDER property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESULT_IN_SAXORDER(String value) {
        this.result_IN_SAXORDER = value;
    }

    /**
     * Gets the value of the terseresponse property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTERSERESPONSE() {
        return terseresponse;
    }

    /**
     * Sets the value of the terseresponse property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTERSERESPONSE(String value) {
        this.terseresponse = value;
    }

    /**
     * Gets the value of the localize_RESULT property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOCALIZE_RESULT() {
        return localize_RESULT;
    }

    /**
     * Sets the value of the localize_RESULT property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOCALIZE_RESULT(String value) {
        this.localize_RESULT = value;
    }

}

==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_functions/gridrequest/GRID.java <==

package net.datastream.schemas.mp_functions.gridrequest;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="GRID_NAME" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="USER_FUNCTION_NAME" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="GRID_ID" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="NUMBER_OF_ROWS_FIRST_RETURNED" type="{http://www.w3.org/2001/XMLSchema}integer" />
 *       &lt;attribute name="CURSOR_POSITION" type="{http://schemas.datastream.net/MP_functions/GridRequest}CURSOR_POSITION" />
 *       &lt;attribute name="TAB_NAME" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="RESULT_IN_SAXORDER" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="TERSERESPONSE" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *       &lt;attribute name="LOCALIZE_RESULT" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
@XmlRootElement(name = "GRID")
public class GRID {

    @XmlAttribute(name = "GRID_NAME")
    protected String grid_NAME;
    @XmlAttribute(name = "USER_FUNCTION_NAME")
    protected String user_FUNCTION_NAME;
    @XmlAttribute(name = "GRID_ID")
    protected BigInteger grid_ID;
    @XmlAttribute(name = "NUMBER_OF_ROWS_FIRST_RETURNED")
    protected BigInteger number_OF_ROWS_FIRST_RETURNED;
    @XmlAttribute(name = "CURSOR_POSITION")
    protected BigInteger cursor_POSITION;
    @XmlAttribute(name = "TAB_NAME")
    protected String tab_NAME;
    @XmlAttribute(name = "RESULT_IN_SAXORDER")
    protected String result_IN_SAXORDER;
    @XmlAttribute(name = "TERSERESPONSE")
    protected String terseresponse;
    @XmlAttribute(name = "LOCALIZE_RESULT")
    protected String localize_RESULT;

    /**
     * Obtient la valeur de la propriété grid_NAME.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGRID_NAME() {
        return grid_NAME;
    }

    /**
     * Définit la valeur de la propriété grid_NAME.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGRID_NAME(String value) {
        this.grid_NAME = value;
    }

    /**
     * Obtient la valeur de la propriété user_FUNCTION_NAME.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSER_FUNCTION_NAME() {
        return user_FUNCTION_NAME;
    }

    /**
     * Définit la valeur de la propriété user_FUNCTION_NAME.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSER_FUNCTION_NAME(String value) {
        this.user_FUNCTION_NAME = value;
    }

    /**
     * Obtient la valeur de la propriété grid_ID.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getGRID_ID() {
        return grid_ID;
    }

    /**
     * Définit la valeur de la propriété grid_ID.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setGRID_ID(BigInteger value) {
        this.grid_ID = value;
    }

    /**
     * Obtient la valeur de la propriété number_OF_ROWS_FIRST_RETURNED.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNUMBER_OF_ROWS_FIRST_RETURNED() {
        return number_OF_ROWS_FIRST_RETURNED;
    }

    /**
     * Définit la valeur de la propriété number_OF_ROWS_FIRST_RETURNED.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNUMBER_OF_ROWS_FIRST_RETURNED(BigInteger value) {
        this.number_OF_ROWS_FIRST_RETURNED = value;
    }

    /**
     * Obtient la valeur de la propriété cursor_POSITION.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getCURSOR_POSITION() {
        return cursor_POSITION;
    }

    /**
     * Définit la valeur de la propriété cursor_POSITION.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setCURSOR_POSITION(BigInteger value) {
        this.cursor_POSITION = value;
    }

    /**
     * Obtient la valeur de la propriété tab_NAME.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTAB_NAME() {
        return tab_NAME;
    }

    /**
     * Définit la valeur de la propriété tab_NAME.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTAB_NAME(String value) {
        this.tab_NAME = value;
    }

    /**
     * Obtient la valeur de la propriété result_IN_SAXORDER.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESULT_IN_SAXORDER() {
        return result_IN_SAXORDER;
    }

    /**
     * Définit la valeur de la propriété result_IN_SAXORDER.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESULT_IN_SAXORDER(String value) {
        this.result_IN_SAXORDER = value;
    }

    /**
     * Obtient la valeur de la propriété terseresponse.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTERSERESPONSE() {
        return terseresponse;
    }

    /**
     * Définit la valeur de la propriété terseresponse.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTERSERESPONSE(String value) {
        this.terseresponse = value;
    }

    /**
     * Obtient la valeur de la propriété localize_RESULT.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOCALIZE_RESULT() {
        return localize_RESULT;
    }

    /**
     * Définit la valeur de la propriété localize_RESULT.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOCALIZE_RESULT(String value) {
        this.localize_RESULT = value;
    }

}
